==> mathjax_2.7.0.orig.tar.xz: MathJax-2.7.0/unpacked/jax/output/HTML-CSS/fonts/STIX-Web/Normal/BoldItalic/Main.js <==
/*************************************************************
 *
 *  MathJax/jax/output/HTML-CSS/fonts/STIX-Web/Normal/BoldItalic/Main.js
 *  
 *  Copyright (c) 2013-2016 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.OutputJax['HTML-CSS'].FONTDATA.FONTS['STIXMathJax_Normal-bold-italic'] = {
  directory: 'Normal/BoldItalic',
  family: 'STIXMathJax_Normal',
  weight: 'bold',
  style: 'italic',
  testString: '\u00A0\uD835\uDC68\uD835\uDC69\uD835\uDC6A\uD835\uDC6B\uD835\uDC6C\uD835\uDC6D\uD835\uDC6E\uD835\uDC6F\uD835\uDC70\uD835\uDC71\uD835\uDC72\uD835\uDC73\uD835\uDC74\uD835\uDC75',
  0x20: [0,0,250,0,0],
  0xA0: [0,0,250,0,0],
  0x1D468: [685,0,759,39,724],
  0x1D469: [669,0,726,42,715],
  0x1D46A: [685,12,701,55,745],
  0x1D46B: [669,0,818,42,790],
  0x1D46C: [669,0,732,42,754],
  0x1D46D: [669,0,635,44,750],
  0x1D46E: [685,12,768,55,768],
  0x1D46F: [669,0,891,42,946],
  0x1D470: [669,0,502,42,557],
  0x1D471: [669,12,558,66,646],
  0x1D472: [669,0,795,42,839],
  0x1D473: [669,0,744,42,700],
  0x1D474: [669,0,1016,42,1071],
  0x1D475: [669,0,869,42,924],
  0x1D476: [685,16,777,55,755],
  0x1D477: [669,0,612,42,733],
  0x1D478: [685,154,810,55,755],
  0x1D479: [669,0,801,42,784],
  0x1D47A: [685,10,671,55,704],
  0x1D47B: [669,0,568,28,700],
  0x1D47C: [669,10,733,72,810],
  0x1D47D: [669,15,593,66,797],
  0x1D47E: [669,17,925,66,1129],
  0x1D47F: [669,0,808,28,830],
  0x1D480: [669,0,549,39,725],
  0x1D481: [669,0,797,66,830],
  0x1D482: [462,10,581,44,548],
  0x1D483: [685,8,509,50,487],
  0x1D484: [462,10,477,44,460],
  0x1D485: [685,14,595,44,589],
  0x1D486: [462,10,498,44,459],
  0x1D487: [685,207,572,44,632],
  0x1D488: [462,203,527,22,527],
  0x1D489: [685,10,576,50,543],
  0x1D48A: [620,9,357,55,300],
  0x1D48B: [620,207,431,-18,414],
  0x1D48C: [685,11,580,55,563],
  0x1D48D: [685,9,346,50,310],
  0x1D48E: [467,9,760,33,727],
  0x1D48F: [467,10,559,33,526],
  0x1D490: [462,10,561,44,539],
  0x1D491: [469,205,571,-33,554],
  0x1D492: [462,205,526,44,532],
  0x1D493: [467,0,441,33,424],
  0x1D494: [462,11,474,55,419],
  0x1D495: [592,10,351,44,318],
  0x1D496: [463,10,535,33,502],
  0x1D497: [473,14,554,52,539],
  0x1D498: [473,14,814,52,799],
  0x1D499: [462,8,587,33,543],
  0x1D49A: [462,205,519,35,522],
  0x1D49B: [462,19,531,35,499],
  0x1D71C: [685,0,759,39,724],
  0x1D71D: [669,0,726,42,715],
  0x1D71E: [669,0,634,42,749],
  0x1D71F: [685,0,632,32,589],
  0x1D720: [669,0,732,42,754],
  0x1D721: [669,0,797,66,830],
  0x1D722: [669,0,891,42,946],
  0x1D723: [685,16,783,55,755],
  0x1D724: [669,0,502,42,557],
  0x1D725: [669,0,795,42,839],
  0x1D726: [685,0,759,39,724],
  0x1D727: [669,0,1016,42,1071],
  0x1D728: [669,0,869,42,924],
  0x1D729: [669,0,718,57,757],
  0x1D72A: [685,16,777,55,755],
  0x1D72B: [669,0,887,39,942],
  0x1D72C: [669,0,612,42,733],
  0x1D72D: [685,16,783,55,755],
  0x1D72E: [669,0,759,64,787],
  0x1D72F: [669,0,568,28,700],
  0x1D730: [685,0,641,31,784],
  0x1D731: [669,0,827,28,799],
  0x1D732: [669,0,808,28,830],
  0x1D733: [685,0,694,30,781],
  0x1D734: [685,0,826,57,815],
  0x1D735: [669,16,632,43,600],
  0x1D736: [461,12,624,44,630],
  0x1D737: [685,205,555,28,583],
  0x1D738: [462,203,490,44,503],
  0x1D739: [685,8,538,44,538],
  0x1D73A: [462,10,495,28,451],
  0x1D73B: [685,203,472,44,522],
  0x1D73C: [462,205,517,33,511],
  0x1D73D: [685,11,566,44,555],
  0x1D73E: [462,9,318,55,274],
  0x1D73F: [462,0,560,55,577],
  0x1D740: [685,16,570,55,537],
  0x1D741: [449,205,636,33,603],
  0x1D742: [459,10,523,55,534],
  0x1D743: [685,203,476,28,487],
  0x1D744: [462,10,561,44,539],
  0x1D745: [449,13,579,39,590],
  0x1D746: [462,205,595,33,562],
  0x1D747: [462,203,480,39,508],
  0x1D748: [449,10,592,44,603],
  0x1D749: [449,7,469,33,502],
  0x1D74A: [462,10,552,33,535],
  0x1D74B: [462,205,706,55,667],
  0x1D74C: [462,204,621,33,676],
  0x1D74D: [462,205,701,33,756],
  0x1D74E: [462,10,687,22,665],
  0x1D74F: [686,10,559,44,559],
  0x1D750: [461,10,481,44,481],
  0x1D751: [698,13,607,33,584],
  0x1D752: [462,15,607,-12,630],
  0x1D753: [685,205,683,44,655],
  0x1D754: [462,205,585,44,563],
  0x1D755: [449,10,868,33,879]
};

MathJax.Callback.Queue(
  ["initFont",MathJax.OutputJax["HTML-CSS"],"STIXMathJax_Normal-bold-italic"],
  ["loadComplete",MathJax.Ajax,MathJax.OutputJax["HTML-CSS"].fontDir+"/Normal/BoldItalic/Main.js"]
);

==> mathjax_2.7.9+dfsg.orig.tar.xz: MathJax-2.7.9/unpacked/jax/output/HTML-CSS/fonts/STIX-Web/Normal/BoldItalic/Main.js <==
/*************************************************************
 *
 *  MathJax/jax/output/HTML-CSS/fonts/STIX-Web/Normal/BoldItalic/Main.js
 *  
 *  Copyright (c) 2013-2020 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.OutputJax['HTML-CSS'].FONTDATA.FONTS['STIXMathJax_Normal-bold-italic'] = {
  directory: 'Normal/BoldItalic',
  family: 'STIXMathJax_Normal',
  weight: 'bold',
  style: 'italic',
  testString: '\u00A0\uD835\uDC68\uD835\uDC69\uD835\uDC6A\uD835\uDC6B\uD835\uDC6C\uD835\uDC6D\uD835\uDC6E\uD835\uDC6F\uD835\uDC70\uD835\uDC71\uD835\uDC72\uD835\uDC73\uD835\uDC74\uD835\uDC75',
  skew: {
    0x1D468: .16,
    0x1D469: .14,
    0x1D46A: .12,
    0x1D46B: .1,
    0x1D46C: .1,
    0x1D46D: .1,
    0x1D46E: .12,
    0x1D46F: .1,
    0x1D470: .1,
    0x1D471: .1,
    0x1D472: .1,
    0x1D473: .05,
    0x1D474: .08,
    0x1D475: .08,
    0x1D476: .12,
    0x1D477: .05,
    0x1D478: .12,
    0x1D479: .1,
    0x1D47A: .12,
    0x1D47D: -.05,
    0x1D47E: -.09,
    0x1D47F: .12,
    0x1D480: -.05,
    0x1D481: .1,
    0x1D482: .09,
    0x1D483: .03,
    0x1D484: .09,
    0x1D485: .22,
    0x1D486: .09,
    0x1D487: .19,
    0x1D488: .08,
    0x1D48A: .1,
    0x1D48B: .16,
    0x1D48D: .09,
    0x1D48E: .09,
    0x1D48F: .05,
    0x1D490: .09,
    0x1D491: .09,
    0x1D492: .1,
    0x1D493: .07,
    0x1D494: .07,
    0x1D495: .09,
    0x1D496: .05,
    0x1D497: .08,
    0x1D498: .1,
    0x1D499: .05,
    0x1D49A: .1,
    0x1D49B: .07,
    0x1D71C: .16,
    0x1D71D: .14,
    0x1D71E: .09,
    0x1D71F: .16,
    0x1D720: .14,
    0x1D721: .14,
    0x1D722: .1,
    0x1D723: .12,
    0x1D724: .1,
    0x1D725: .12,
    0x1D726: .16,
    0x1D727: .11,
    0x1D728: .1,
    0x1D729: .14,
    0x1D72A: .14,
    0x1D72B: .12,
    0x1D72C: .08,
    0x1D72D: .14,
    0x1D72E: .14,
    0x1D731: .12,
    0x1D732: .14,
    0x1D734: .16,
    0x1D735: .05,
    0x1D736: .05,
    0x1D737: .1,
    0x1D738: .05,
    0x1D739: .12,
    0x1D73A: .07,
    0x1D73B: .09,
    0x1D73C: .07,
    0x1D73D: .1,
    0x1D73E: .05,
    0x1D740: .07,
    0x1D741: .1,
    0x1D742: .07,
    0x1D743: .12,
    0x1D744: .08,
    0x1D745: .08,
    0x1D746: .1,
    0x1D747: .1,
    0x1D748: .05,
    0X1D749: .05,
    0x1D74A: .05,
    0x1D74B: .05,
    0x1D74C: .09,
    0x1D74E: .05,
    0x1D750: .1,
    0x1D751: .1,
    0X1D752: .05,
    0X1D753: .12,
    0x1D754: .1,
    0x1D755: .09,
  },
  0x20: [0,0,250,0,0],
  0xA0: [0,0,250,0,0],
  0x1D468: [685,0,759,39,724],
  0x1D469: [669,0,726,42,715],
  0x1D46A: [685,12,701,55,745],
  0x1D46B: [669,0,818,42,790],
  0x1D46C: [669,0,732,42,754],
  0x1D46D: [669,0,635,44,750],
  0x1D46E: [685,12,768,55,768],
  0x1D46F: [669,0,891,42,946],
  0x1D470: [669,0,502,42,557],
  0x1D471: [669,12,558,66,646],
  0x1D472: [669,0,795,42,839],
  0x1D473: [669,0,744,42,700],
  0x1D474: [669,0,1016,42,1071],
  0x1D475: [669,0,869,42,924],
  0x1D476: [685,16,777,55,755],
  0x1D477: [669,0,612,42,733],
  0x1D478: [685,154,810,55,755],
  0x1D479: [669,0,801,42,784],
  0x1D47A: [685,10,671,55,704],
  0x1D47B: [669,0,568,28,700],
  0x1D47C: [669,10,733,72,810],
  0x1D47D: [669,15,593,66,797],
  0x1D47E: [669,17,925,66,1129],
  0x1D47F: [669,0,808,28,830],
  0x1D480: [669,0,549,39,725],
  0x1D481: [669,0,797,66,830],
  0x1D482: [462,10,581,44,548],
  0x1D483: [685,8,509,50,487],
  0x1D484: [462,10,477,44,460],
  0x1D485: [685,14,595,44,589],
  0x1D486: [462,10,498,44,459],
  0x1D487: [685,207,572,44,632],
  0x1D488: [462,203,527,22,527],
  0x1D489: [685,10,576,50,543],
  0x1D48A: [620,9,357,55,300],
  0x1D48B: [620,207,431,-18,414],
  0x1D48C: [685,11,580,55,563],
  0x1D48D: [685,9,346,50,310],
  0x1D48E: [467,9,760,33,727],
  0x1D48F: [467,10,559,33,526],
  0x1D490: [462,10,561,44,539],
  0x1D491: [469,205,571,-33,554],
  0x1D492: [462,205,526,44,532],
  0x1D493: [467,0,441,33,424],
  0x1D494: [462,11,474,55,419],
  0x1D495: [592,10,351,44,318],
  0x1D496: [463,10,535,33,502],
  0x1D497: [473,14,554,52,539],
  0x1D498: [473,14,814,52,799],
  0x1D499: [462,8,587,33,543],
  0x1D49A: [462,205,519,35,522],
  0x1D49B: [462,19,531,35,499],
  0x1D71C: [685,0,759,39,724],
  0x1D71D: [669,0,726,42,715],
  0x1D71E: [669,0,634,42,749],
  0x1D71F: [685,0,632,32,589],
  0x1D720: [669,0,732,42,754],
  0x1D721: [669,0,797,66,830],
  0x1D722: [669,0,891,42,946],
  0x1D723: [685,16,783,55,755],
  0x1D724: [669,0,502,42,557],
  0x1D725: [669,0,795,42,839],
  0x1D726: [685,0,759,39,724],
  0x1D727: [669,0,1016,42,1071],
  0x1D728: [669,0,869,42,924],
  0x1D729: [669,0,718,57,757],
  0x1D72A: [685,16,777,55,755],
  0x1D72B: [669,0,887,39,942],
  0x1D72C: [669,0,612,42,733],
  0x1D72D: [685,16,783,55,755],
  0x1D72E: [669,0,759,64,787],
  0x1D72F: [669,0,568,28,700],
  0x1D730: [685,0,641,31,784],
  0x1D731: [669,0,827,28,799],
  0x1D732: [669,0,808,28,830],
  0x1D733: [685,0,694,30,781],
  0x1D734: [685,0,826,57,815],
  0x1D735: [669,16,632,43,600],
  0x1D736: [461,12,624,44,630],
  0x1D737: [685,205,555,28,583],
  0x1D738: [462,203,490,44,503],
  0x1D739: [685,8,538,44,538],
  0x1D73A: [462,10,495,28,451],
  0x1D73B: [685,203,472,44,522],
  0x1D73C: [462,205,517,33,511],
  0x1D73D: [685,11,566,44,555],
  0x1D73E: [462,9,318,55,274],
  0x1D73F: [462,0,560,55,577],
  0x1D740: [685,16,570,55,537],
  0x1D741: [449,205,636,33,603],
  0x1D742: [459,10,523,55,534],
  0x1D743: [685,203,476,28,487],
  0x1D744: [462,10,561,44,539],
  0x1D745: [449,13,579,39,590],
  0x1D746: [462,205,595,33,562],
  0x1D747: [462,203,480,39,508],
  0x1D748: [449,10,592,44,603],
  0x1D749: [449,7,469,33,502],
  0x1D74A: [462,10,552,33,535],
  0x1D74B: [462,205,706,55,667],
  0x1D74C: [462,204,621,33,676],
  0x1D74D: [462,205,701,33,756],
  0x1D74E: [462,10,687,22,665],
  0x1D74F: [686,10,559,44,559],
  0x1D750: [461,10,481,44,481],
  0x1D751: [698,13,607,33,584],
  0x1D752: [462,15,607,-12,630],
  0x1D753: [685,205,683,44,655],
  0x1D754: [462,205,585,44,563],
  0x1D755: [449,10,868,33,879]
};

MathJax.Callback.Queue(
  ["initFont",MathJax.OutputJax["HTML-CSS"],"STIXMathJax_Normal-bold-italic"],
  ["loadComplete",MathJax.Ajax,MathJax.OutputJax["HTML-CSS"].fontDir+"/Normal/BoldItalic/Main.js"]
);
